@@ -4,7 +4,9 @@
 export BORG_RELOCATED_REPO_ACCESS_IS_OK=yes
 
 # Define the repository and archive name
-REPO="/mnt/borgbackup"
+BASE_REPO_PATH="/mnt/borgbackup"
+REPO="${BASE_REPO_PATH}/$(hostname -s)"
+
 
 # Distribution-ID aus der os-release-Datei extrahieren
 DISTRIB_ID=$(grep '^ID=' /etc/os-release | cut -d= -f2 | tr -d '"')
